@@ -25,25 +25,17 @@ namespace
 // notified, if the slot_rep is deleted when they call disconnect().
 struct destroy_notify_struct
 {
-  destroy_notify_struct() noexcept : deleted_(false) { }
+  destroy_notify_struct() : deleted_(false) { }
 
-  static void* notify(void* data) noexcept
+  static void* notify(void* data)
   {
-    auto self_ = reinterpret_cast<destroy_notify_struct*>(data);
+    destroy_notify_struct* self_ = reinterpret_cast<destroy_notify_struct*>(data);
     self_->deleted_ = true;
-    return nullptr;
+    return 0;
   }
 
   bool deleted_;
 };
-
-// Used by slot_base::set_parent() when a slot_base without a rep_ is assigned a parent.
-class dummy_slot_rep : public sigc::internal::slot_rep
-{
-public:
-  dummy_slot_rep() : slot_rep(nullptr, nullptr, &clone) {}
-  static void* clone(void*) { return new dummy_slot_rep(); }
-};
 } // anonymous namespace
 
 namespace sigc
@@ -63,30 +55,31 @@ void slot_rep::operator delete(void* p)
 }
 #endif
 
+//TODO: When we can break API: Is it necessary to invalidate the slot here?
+// If the parent misbehaves, when the slot is not invalidated, isn't that
+// a problem that should be fixed in the parent?
+// See discussion in https://bugzilla.gnome.org/show_bug.cgi?id=738602
 void slot_rep::disconnect()
 {
-  // Invalidate the slot.
-  // _Must_ be done here because parent_ might defer the actual
-  // destruction of the slot_rep and try to invoke it before that point.
-  // Must be done also for a slot without a parent, according to
-  // https://bugzilla.gnome.org/show_bug.cgi?id=311057
-  // See also https://bugzilla.gnome.org/show_bug.cgi?id=738602
-  call_ = nullptr;
-
   if (parent_)
   {
-    auto data_ = parent_;
-    parent_ = nullptr;  // Just a precaution.
+    call_ = 0;          // Invalidate the slot.
+                        // _Must_ be done here because parent_ might defer the actual
+                        // destruction of the slot_rep and try to invoke it before that point.
+    void* data_ = parent_;
+    parent_ = 0;        // Just a precaution.
     (cleanup_)(data_);  // Notify the parent (might lead to destruction of this!).
   }
+  else
+    call_ = 0;
 }
 
 //static
 void* slot_rep::notify(void* data)
 {
-  auto self_ = reinterpret_cast<slot_rep*>(data);
+  slot_rep* self_ = reinterpret_cast<slot_rep*>(data);
 
-  self_->call_ = nullptr; // Invalidate the slot.
+  self_->call_ = 0; // Invalidate the slot.
   
   // Make sure we are notified if disconnect() deletes self_, which is trackable.
   destroy_notify_struct notifier;
@@ -99,23 +92,23 @@ void* slot_rep::notify(void* data)
     self_->destroy(); // Detach the stored functor from the other referred trackables and destroy it.
                       // destroy() might lead to deletion of self_. Bug #564005.
   }
-  return nullptr;
+  return 0;
 }
 
 } // namespace internal
   
-slot_base::slot_base() noexcept
-: rep_(nullptr),
+slot_base::slot_base()
+: rep_(0),
   blocked_(false)
 {}
 
-slot_base::slot_base(rep_type* rep) noexcept
+slot_base::slot_base(rep_type* rep)
 : rep_(rep),
   blocked_(false)
 {}
 
 slot_base::slot_base(const slot_base& src)
-: rep_(nullptr),
+: rep_(0),
   blocked_(src.blocked_)
 {
   if (src.rep_)
@@ -132,88 +125,46 @@ slot_base::slot_base(const slot_base& src)
   }
 }
 
-slot_base::slot_base(slot_base&& src)
-: rep_(nullptr),
-  blocked_(src.blocked_)
-{
-  if (src.rep_)
-  {
-    if (src.rep_->parent_)
-    {
-      // src is connected to a parent, e.g. a sigc::signal.
-      // Copy, don't move! See https://bugzilla.gnome.org/show_bug.cgi?id=756484
-
-      //Check call_ so we can ignore invalidated slots.
-      //Otherwise, destroyed bound reference parameters (whose destruction
-      //caused the slot's invalidation) may be used during dup().
-      if (src.rep_->call_)
-        rep_ = src.rep_->dup();
-      else
-        blocked_ = false; //Return the default invalid slot.
-    }
-    else
-    {
-      // src is not connected. Really move src.rep_.
-      src.rep_->notify_callbacks();
-      rep_ = src.rep_;
-
-      //Wipe src:
-      src.rep_ = nullptr;
-      src.blocked_ = false;
-    }
-  }
-}
-
 slot_base::~slot_base()
 {
   if (rep_)
     delete rep_;
 }
 
-slot_base::operator bool() const noexcept
+slot_base::operator bool() const
 {
-  return rep_ != nullptr;
-}
-
-void slot_base::delete_rep_with_check()
-{
-  if (!rep_)
-    return;
-
-  // Make sure we are notified if disconnect() deletes rep_, which is trackable.
-  // Compare slot_rep::notify().
-  destroy_notify_struct notifier;
-  rep_->add_destroy_notify_callback(&notifier, destroy_notify_struct::notify);
-  rep_->disconnect(); // Disconnect the slot (might lead to deletion of rep_!).
-
-  // If rep_ has been deleted, don't try to delete it again.
-  // If it has been deleted, this slot_base has probably also been deleted, so
-  // don't clear the rep_ pointer. It's the responsibility of the code that
-  // deletes rep_ to either clear the rep_ pointer or delete this slot_base.
-  if (!notifier.deleted_)
-  {
-    rep_->remove_destroy_notify_callback(&notifier);
-    delete rep_; // Detach the stored functor from the other referred trackables and destroy it.
-    rep_ = nullptr;
-  }
+  return rep_ != 0;
 }
 
 slot_base& slot_base::operator=(const slot_base& src)
 {
-  if (src.rep_ == rep_)
-  {
-    blocked_ = src.blocked_;
-    return *this;
-  }
+  if (src.rep_ == rep_) return *this;
 
   if (src.empty())
   {
-    delete_rep_with_check();
+    if (rep_)
+    {
+      // Make sure we are notified if disconnect() deletes rep_, which is trackable.
+      // Compare slot_rep::notify().
+      destroy_notify_struct notifier;
+      rep_->add_destroy_notify_callback(&notifier, destroy_notify_struct::notify);
+      rep_->disconnect(); // Disconnect the slot (might lead to deletion of rep_!).
 
+      // If rep_ has been deleted, don't try to delete it again.
+      // If it has been deleted, this slot_base has probably also been deleted, so
+      // don't clear the rep_ pointer. It's the responsibility of the code that
+      // deletes rep_ to either clear the rep_ pointer or delete this slot_base.
+      if (!notifier.deleted_)
+      {
+        rep_->remove_destroy_notify_callback(&notifier);
+        delete rep_; // Detach the stored functor from the other referred trackables and destroy it.
+        rep_ = 0;
+      }
+    }
     return *this;
   }
 
-  auto new_rep_ = src.rep_->dup();
+  internal::slot_rep* new_rep_ = src.rep_->dup();
 
   if (rep_) // Silently exchange the slot_rep.
   {
@@ -222,58 +173,14 @@ slot_base& slot_base::operator=(const slot_base& src)
   }
 
   rep_ = new_rep_;
-  blocked_ = src.blocked_;
 
   return *this;
 }
 
-slot_base& slot_base::operator=(slot_base&& src)
+void slot_base::set_parent(void* parent, void* (*cleanup)(void*)) const
 {
-  if (src.rep_ == rep_)
-  {
-    blocked_ = src.blocked_;
-    return *this;
-  }
-
-  if (src.empty())
-  {
-    delete_rep_with_check();
-    return *this;
-  }
-
-  blocked_ = src.blocked_;
-  internal::slot_rep* new_rep_ = nullptr;
-  if (src.rep_->parent_)
-  {
-    // src is connected to a parent, e.g. a sigc::signal.
-    // Copy, don't move! See https://bugzilla.gnome.org/show_bug.cgi?id=756484
-    new_rep_ = src.rep_->dup();
-  }
-  else
-  {
-    // src is not connected. Really move src.rep_.
-    src.rep_->notify_callbacks();
-    new_rep_ = src.rep_;
-
-    //Wipe src:
-    src.rep_ = nullptr;
-    src.blocked_ = false;
-  }
-
-  if (rep_) // Silently exchange the slot_rep.
-  {
-    new_rep_->set_parent(rep_->parent_, rep_->cleanup_);
-    delete rep_; // Calls destroy(), but does not call disconnect().
-  }
-  rep_ = new_rep_;
-  return *this;
-}
-
-void slot_base::set_parent(void* parent, void* (*cleanup)(void*)) const noexcept
-{
-  if (!rep_)
-    rep_ = new dummy_slot_rep();
-  rep_->set_parent(parent, cleanup);
+  if (rep_)
+    rep_->set_parent(parent, cleanup);
 }
 
 void slot_base::add_destroy_notify_callback(void* data, func_destroy_notify func) const
@@ -288,14 +195,14 @@ void slot_base::remove_destroy_notify_callback(void* data) const
     rep_->remove_destroy_notify_callback(data);
 }
 
-bool slot_base::block(bool should_block) noexcept
+bool slot_base::block(bool should_block)
 {
   bool old = blocked_;
   blocked_ = should_block;
   return old;
 }
 
-bool slot_base::unblock() noexcept
+bool slot_base::unblock()
 {
   return block(false);
 }
@@ -312,9 +219,9 @@ void slot_base::disconnect()
   if (rep_ && !rep_->call_)
     {
       delete rep_;        // This is not strictly necessary here. I'm convinced that it is
-      rep_ = nullptr;           // safe to wait for the destructor to delete the slot_rep. Martin.
+      rep_ = 0;           // safe to wait for the destructor to delete the slot_rep. Martin.
     }
-  return (rep_ == nullptr);
+  return (rep_ == 0);
 }*/
 
 } //namespace sigc
