@@ -212,7 +212,7 @@ T_CppObject* RefPtr<T_CppObject>::operator->() const
 template <class T_CppObject> inline
 RefPtr<T_CppObject>::RefPtr()
 :
-  pCppObject_ (nullptr)
+  pCppObject_ (0)
 {}
 
 template <class T_CppObject> inline
@@ -257,7 +257,7 @@ RefPtr<T_CppObject>::RefPtr(const RefPtr<T_CastFrom>& src)
 template <class T_CppObject> inline
 void RefPtr<T_CppObject>::swap(RefPtr<T_CppObject>& other)
 {
-  const auto temp = pCppObject_;
+  T_CppObject *const temp = pCppObject_;
   pCppObject_ = other.pCppObject_;
   other.pCppObject_ = temp;
 }
@@ -319,7 +319,7 @@ bool RefPtr<T_CppObject>::operator!=(const RefPtr<T_CppObject>& src) const
 template <class T_CppObject> inline
 RefPtr<T_CppObject>::operator bool() const
 {
-  return (pCppObject_ != nullptr);
+  return (pCppObject_ != 0);
 }
 
 #ifndef GLIBMM_DISABLE_DEPRECATED
@@ -342,7 +342,7 @@ template <class T_CppObject>
 inline
 RefPtr<T_CppObject> RefPtr<T_CppObject>::cast_dynamic(const RefPtr<T_CastFrom>& src)
 {
-  const auto pCppObject = dynamic_cast<T_CppObject*>(src.operator->());
+  T_CppObject *const pCppObject = dynamic_cast<T_CppObject*>(src.operator->());
 
   if(pCppObject)
     pCppObject->reference();
@@ -355,7 +355,7 @@ template <class T_CppObject>
 inline
 RefPtr<T_CppObject> RefPtr<T_CppObject>::cast_static(const RefPtr<T_CastFrom>& src)
 {
-  const auto pCppObject = static_cast<T_CppObject*>(src.operator->());
+  T_CppObject *const pCppObject = static_cast<T_CppObject*>(src.operator->());
 
   if(pCppObject)
     pCppObject->reference();
@@ -368,7 +368,7 @@ template <class T_CppObject>
 inline
 RefPtr<T_CppObject> RefPtr<T_CppObject>::cast_const(const RefPtr<T_CastFrom>& src)
 {
-  const auto pCppObject = const_cast<T_CppObject*>(src.operator->());
+  T_CppObject *const pCppObject = const_cast<T_CppObject*>(src.operator->());
 
   if(pCppObject)
     pCppObject->reference();
@@ -470,12 +470,12 @@ public:
 
 int main(int argc, char* argv[])
 {
-  auto util = TestUtilities::get_instance();
+  TestUtilities* util = TestUtilities::get_instance();
 
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 
-  auto test = new Test;
+  Test* test = new Test;
 
   test->action->emit_sig1(23);
   delete test;
