@@ -34,23 +34,23 @@ public:
 
 int main(int argc, char* argv[])
 {
-  auto util = TestUtilities::get_instance();
+  TestUtilities* util = TestUtilities::get_instance();
 
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 
-  auto instance = new Derived();
-  sigc::slot<void> handler = sigc::mem_fun(*instance, &Derived::method);
+  Derived* instance = new Derived();
+  sigc::slot<void> handler = sigc::mem_fun(instance, &Derived::method);
   handler();
   util->check_result(result_stream, "method()");
 
   sigc::slot<void> param =
-    sigc::bind(sigc::slot<void, Derived&>(), std::ref(*instance));
+    sigc::bind(sigc::slot<void, Derived&>(), sigc::ref(*instance));
   param();
   util->check_result(result_stream, "");
 
   sigc::slot<Derived> ret =
-    sigc::bind_return(sigc::slot<void>(), std::ref(*instance));
+    sigc::bind_return(sigc::slot<void>(), sigc::ref(*instance));
   ret();
   util->check_result(result_stream, "");
 
