@@ -21,8 +21,8 @@
 // - Show that a slot with a C++11 lambda expression can be automatically
 //   disconnected when an object derived from sigc::trackable is deleted,
 //   provided sigc::track_obj() is used.
-//   It shows that C++11 lambda expressions can replace the libsigc++ lambda
-//   expressions, which have been removed.
+//   It's shown here as a preparation for deprecating and eventually
+//   deleting the libsigc++ lambda expressions.
 //   See https://bugzilla.gnome.org/show_bug.cgi?id=672555
 // - Test the code example in the documentation in sigc++/adaptors/track_obj.h.
 //
@@ -33,6 +33,9 @@
 //   echo $?
 // If test_track_obj writes nothing and the return code is 0, the test has passed.
 
+#if __cplusplus >= 201103L || defined(__GXX_EXPERIMENTAL_CXX0X__) || _MSC_VER >= 1700
+#  define USING_CPP11_LAMBDA_EXPRESSIONS
+#endif
 
 #include "testutilities.h"
 #include <string>
@@ -42,6 +45,12 @@
 #include <sigc++/adaptors/track_obj.h>
 #include <sigc++/signal.h>
 
+#ifdef USING_CPP11_LAMBDA_EXPRESSIONS
+namespace sigc
+{
+  SIGC_FUNCTORS_DEDUCE_RESULT_TYPE_WITH_DECLTYPE
+}
+#endif
 
 namespace
 {
@@ -72,8 +81,7 @@ public:
     return (i<0) ? "negative" : ((i>0) ? "positive" : "zero");
   }
 
-protected:
-  // Don't make it private. clang++ does not like unused private data.
+private:
   const bar_group4& bar_;
 };
 
@@ -93,14 +101,12 @@ public:
     return result;
   }
 
-protected:
-  // Don't make it private. clang++ does not like unused private data.
-  const bar_group4& bar_;
 private:
+  const bar_group4& bar_;
   const book& aBook_;
 };
 
-//C++11 lamba expressions:
+#ifdef USING_CPP11_LAMBDA_EXPRESSIONS
 
 inline std::ostringstream& operator << (std::ostringstream& s, const book& b)
 {
@@ -118,13 +124,14 @@ void foo_group4(bar_group4&)
 {
   result_stream << "foo_group4(bar_group4&)";
 }
+#endif // USING_CPP11_LAMBDA_EXPRESSIONS
 
 } // end anonymous namespace
 
 
 int main(int argc, char* argv[])
 {
-  auto util = TestUtilities::get_instance();
+  TestUtilities* util = TestUtilities::get_instance();
 
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
@@ -143,7 +150,7 @@ int main(int argc, char* argv[])
 
   // Allocate on the heap. valgrind can then find erroneous memory accesses.
   // (There should be none, of course.)
-  auto psl2 = new sigc::slot<std::string, int, std::string>;
+  sigc::slot<std::string, int, std::string>* psl2 = new sigc::slot<std::string, int, std::string>;
   bar_group4* pbar4 = new bar_group4;
   book* pbook4 = new book("A Book");
   *psl2 = sigc::track_obj(Functor2(*pbar4, *pbook4), *pbar4, *pbook4);
@@ -151,16 +158,15 @@ int main(int argc, char* argv[])
   util->check_result(result_stream, "zero, Book title: A Book");
 
   delete pbook4; // auto-disconnect *psl2
-  pbook4 = nullptr;
+  pbook4 = 0;
   result_stream << (*psl2)(0, "Book title: ");
   util->check_result(result_stream, "");
   delete psl2;
-  psl2 = nullptr;
+  psl2 = 0;
   delete pbar4;
-  pbar4 = nullptr;
+  pbar4 = 0;
 
-
-//C++11 lambda expressions:
+#ifdef USING_CPP11_LAMBDA_EXPRESSIONS
 
   // auto-disconnect
   // If you want to auto-disconnect a slot with a C++11 lambda expression
@@ -205,10 +211,10 @@ int main(int argc, char* argv[])
     sigc::signal<void> some_signal;
     {
       bar_group4 some_bar;
-      //some_signal.connect(sigc::group(&foo,std::ref(some_bar)));
+      //some_signal.connect(sigc::group(&foo,sigc::ref(some_bar)));
       // disconnected automatically if some_bar goes out of scope
       //some_signal.connect([&some_bar](){ foo_group4(some_bar); }); // no auto-disconnect
-      //some_signal.connect(sigc::bind(&foo_group4, std::ref(some_bar))); // auto-disconnects, but we prefer C++11 lambda
+      //some_signal.connect(sigc::bind(&foo_group4, sigc::ref(some_bar))); // auto-disconnects, but we prefer C++11 lambda
       some_signal.connect(sigc::track_obj([&some_bar](){ foo_group4(some_bar); }, some_bar));
       some_signal.emit();
       util->check_result(result_stream, "foo_group4(bar_group4&)");
@@ -219,6 +225,9 @@ int main(int argc, char* argv[])
     util->check_result(result_stream, "");
   }
 
+#else // not USING_CPP11_LAMBDA_EXPRESSIONS
+  std::cout << "The compiler capabilities don't allow test of C++11 lambda expressions." << std::endl;
+#endif
 
   return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 }
