@@ -90,7 +90,7 @@ struct MyAdaptor1 : public sigc::adapts<T_functor>
 {
   template <class T_arg1=void, class T_arg2=void>
   struct deduce_result_type
-  { typedef sigc::deduce_result_t<T_functor, T_arg1, T_arg2> type; };
+  { typedef typename sigc::deduce_result_type<T_functor, T_arg1, T_arg2>::type type; };
   typedef typename sigc::functor_trait<T_functor>::result_type result_type;
 
   result_type
@@ -158,7 +158,7 @@ struct visitor<ns1::MyAdaptor1<T_functor> >
 
 int main(int argc, char* argv[])
 {
-  auto util = TestUtilities::get_instance();
+  TestUtilities* util = TestUtilities::get_instance();
 
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
@@ -167,7 +167,7 @@ int main(int argc, char* argv[])
 
   {
     MyClass1 my_class1("x=");
-    sl1 = sigc::mem_fun(my_class1, &MyClass1::execute);
+    sl1 = sigc::mem_fun(&my_class1, &MyClass1::execute);
     sl1(-2);
     util->check_result(result_stream, "x=-2");
 
@@ -179,7 +179,7 @@ int main(int argc, char* argv[])
 #if SIGCTEST_CASE >= 2
   {
     MyClass2 my_class2("y=");
-    sl1 = sigc::mem_fun(my_class2, &MyClass2::execute);
+    sl1 = sigc::mem_fun(&my_class2, &MyClass2::execute);
     sl1(2);
     util->check_result(result_stream, "y=2");
 
@@ -191,7 +191,7 @@ int main(int argc, char* argv[])
 
   {
     MyClass1 my_class3("a=");
-    sl1 = ns1::my_adaptor1(sigc::mem_fun(my_class3, &MyClass1::execute));
+    sl1 = ns1::my_adaptor1(sigc::mem_fun(&my_class3, &MyClass1::execute));
     sl1(42);
     util->check_result(result_stream, "MyAdaptor1()(_A_arg1) a=42");
 
